@@ -13,6 +13,7 @@
 # limitations under the License.
 #
 
+import ferry.install
 import logging
 from subprocess import Popen, PIPE
 from ferry.docker.docker import DockerCLI
@@ -26,6 +27,14 @@ class DockerFabric(object):
         self.docker_user = 'root'
         self.cli = DockerCLI()
 
+    """
+    Read the location of the directory containing the keys
+    used to communicate with the containers. 
+    """
+    def _read_key_dir(self):
+        f = open(ferry.install.DEFAULT_DOCKER_KEY, 'r')
+        return f.read().strip()
+ 
     """
     Fetch the current docker version.
     """
@@ -138,10 +147,12 @@ class DockerFabric(object):
     """
     def cmd(self, containers, cmd):
         all_output = {}
+        key = self._read_key_dir() + '/id_rsa'
         for c in containers:
-            ssh_cmd = 'ssh -t -t ' + self.docker_user + '@' + c.internal_ip + ' \'%s\'' % cmd
-            logging.warning(ssh_cmd)
-            output = Popen(ssh_cmd, stdout=PIPE, shell=True).stdout.read()
+            ip = self.docker_user + '@' + c.internal_ip
+            ssh = 'ssh -o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null -i ' + key + ' -t -t ' + ip + ' \'%s\'' % cmd
+            logging.warning(ssh)
+            output = Popen(ssh, stdout=PIPE, shell=True).stdout.read()
             all_output[c] = output.strip()
 
         return all_output
